#
# spec file for package tlrc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tlrc
Version:        1.10.0
Release:        1.1
Summary:        A tldr-pages client written in Rust
License:        MIT
URL:            https://tldr.sh/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
# Seems there is already another tldr-pages client
# Well but tlrc is the official one :)
Conflicts:      tealdeer

%description
The tldr-pages project is a collection of community-maintained help pages for command-line tools, that aims to be a simpler, more approachable complement to traditional man pages.

%prep
%autosetup -p1 -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/tldr

%changelog
* Mon Feb 10 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.10.0:
  * Fixed stretched man page rendering when using mandoc
  * Fixed wrong error messages when the pages.en directory in the
    cache is empty
  * The location of the config file can now be overridden using
    the TLRC_CONFIG environment variable (#89)
  * Added support for hex color codes (#115)
* Tue Jul 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.3:
  * Use native TLS certificates instead of webpki-roots
  * ~ in the config now expands to the user's home directory (#80)
  * Fixed wrong next automatic update time in tldr --offline --info
  * Fixed extraction of files that contain .. in the path from zip archives
* Tue Apr 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.2:
  * Enable SOCKS proxy support (#71)
  * Fixed error messages being put on the same line as the previous
    info message
  * Fixed wrong background colors of empty lines if a background
    color is set in the config
  * Bump rustls from 0.22.3 to 0.22.4 (#72) bsc#1223243 CVE-2024-32650
* Fri Mar 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.1:
  * Fixed language detection issues when languages = [] is set
    in the config (#69)
* Mon Mar 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.0:
  * Client specification v2.2
  * Fixed rendering of triple brace placeholders ({{{ ... }}} no
    longer shows one brace outside)
  * On --update, the new sha256sums will be compared to the old ones
    and archives that haven't been updated won't be downloadedanymore
  * Improved shell completions (#50)
  * New config option: cache.mirror
  * The default mirror has been changed from
  https://raw.githubusercontent.com/tldr-pages/tldr-pages.github.io/main/assets to
  https://github.com/tldr-pages/tldr/releases/latest/download as
  per the new client specification
* Wed Dec 13 2023 Michael Vetter <mvetter@suse.com>
- Initial package of tlrc 1.8.0 for openSUSE
